@@ -2,6 +2,7 @@ import unittest
 import bz2
 import bmemcached
 
+
 class MemcachedTests(unittest.TestCase):
     def setUp(self):
         self.server = '127.0.0.1:11211'
@@ -11,22 +12,22 @@ class MemcachedTests(unittest.TestCase):
         self.data = b'this is test data. ' * 32
 
     def tearDown(self):
-        self.client.delete(b'test_key')
-        self.client.delete(b'test_key2')
+        self.client.delete('test_key')
+        self.client.delete('test_key2')
         self.client.disconnect_all()
         self.bzclient.disconnect_all()
 
     def testCompressedData(self):
-        self.client.set(b'test_key', self.data)
-        self.assertEqual(self.data, self.client.get(b'test_key'))
+        self.client.set('test_key', self.data)
+        self.assertEqual(self.data, self.client.get('test_key'))
 
     def testBZ2CompressedData(self):
-        self.bzclient.set(b'test_key', self.data)
-        self.assertEqual(self.data, self.bzclient.get(b'test_key'))
+        self.bzclient.set('test_key', self.data)
+        self.assertEqual(self.data, self.bzclient.get('test_key'))
 
     def testCompressionMissmatch(self):
-        self.client.set(b'test_key', self.data)
-        self.bzclient.set(b'test_key2', self.data)
-        self.assertEqual(self.client.get(b'test_key'),
-                self.bzclient.get(b'test_key2'))
-        self.assertRaises(IOError, self.bzclient.get, b'test_key')
+        self.client.set('test_key', self.data)
+        self.bzclient.set('test_key2', self.data)
+        self.assertEqual(self.client.get('test_key'),
+                self.bzclient.get('test_key2'))
+        self.assertRaises(IOError, self.bzclient.get, 'test_key')
