@@ -1,3 +1,5 @@
+from io import BytesIO
+
 try:
     import cPickle as pickle
 except ImportError:
@@ -6,17 +8,29 @@ import json
 import unittest
 import bmemcached
 
+
 class JsonPickler(object):
+
     def __init__(self, f, protocol=0):
         self.f = f
 
     def dump(self, obj):
+        # if isinstance(obj, str):
+        #     obj = obj.encode()
+
+        if isinstance(self.f, BytesIO):
+            return self.f.write(json.dumps(obj).encode())
+
         return json.dump(obj, self.f)
 
     def load(self):
+        if isinstance(self.f, BytesIO):
+            return json.loads(self.f.read().decode())
         return json.load(self.f)
 
+
 class MemcachedTests(unittest.TestCase):
+
     def setUp(self):
         self.server = '127.0.0.1:11211'
         self.dclient = bmemcached.Client(self.server, 'user', 'password')
@@ -26,18 +40,18 @@ class MemcachedTests(unittest.TestCase):
         self.data = {'a': 'b'}
 
     def tearDown(self):
-        self.jclient.delete(b'test_key')
+        self.jclient.delete('test_key')
         self.jclient.disconnect_all()
         self.dclient.disconnect_all()
 
     def testJson(self):
-        self.jclient.set(b'test_key', self.data)
-        self.assertEqual(self.data, self.jclient.get(b'test_key'))
+        self.jclient.set('test_key', self.data)
+        self.assertEqual(self.data, self.jclient.get('test_key'))
 
     def testDefaultVsJson(self):
-        self.dclient.set(b'test_key', self.data)
-        self.assertRaises(ValueError, self.jclient.get, b'test_key')
+        self.dclient.set('test_key', self.data)
+        self.assertRaises(ValueError, self.jclient.get, 'test_key')
 
     def testJsonVsDefault(self):
-        self.jclient.set(b'test_key', self.data)
-        self.assertRaises(pickle.UnpicklingError, self.dclient.get, b'test_key')
+        self.jclient.set('test_key', self.data)
+        self.assertRaises(pickle.UnpicklingError, self.dclient.get, 'test_key')
